ApiResponse

Struct ApiResponse 

pub struct ApiResponse<S> { /* private fields */ }
A response that may be returned from an axum handler, with a flexible set of response types.

It implements

  • IntoResponse
  • Optionally aide::OperationOutput when the aide feature is enabled, and all responses implement OperationOutput as well.
  • Optionally [utoipa::ToResponse] when the utoipa feature is enabled, and all responses implement ToResponse as well.

Simply specify the set of response types that this handler may return as a tuple in the ApiResponse type:

  • ApiResponse<(BadRequest<String>,)>
  • ApiResponse<(BadRequest<String>, Internal<String>)>
  • ApiResponse<(BadRequest<String>, Internal<String>, Forbidden<String>)>

ApiResponse<S> implements From<T> for any T contained in the set S, allowing for easy error propagation. See ResultStatusExt for convenient methods to help with error propagation.

Be aware that IntoResponse is called whenever this type is constructed, not when it is returned by the handler. This behaviour differs from standard axum.

Normally, this type is used as Result<T, ApiResponse<S>> (or the type-alias ApiResult). It can also be used itself as a direct return type from an axum handler.

Examples

// An very basic axum-handler. See the `examples` directory for more complete examples.
async fn handler() -> Result<(), ApiResponse<(NotFound<String>, BadRequest<String>)> { todo!() }

Implementations

Source

impl<S> ApiResponse<S>

pub fn new<T>(wrapper: T) -> Self
where S: Contains<T>, T: StatusProvider<Inner: IntoResponse>,

Create a new ApiResponse from a status wrapper.

pub fn new_unchecked(response: impl IntoResponse, code: StatusCode) -> Self

Create a new ApiResponse from a raw response and status code, without checking if it is valid

pub fn into_parts(self) -> (Response, StatusCode)

Decompose the ApiResponse into its raw response and status code.

pub fn into_superset<U>(self) -> ApiResponse<U>
where U: Superset<S>,

Convert this ApiResponse into a new ApiResponse with a superset of the original error types.