pub type ApiResult<T, S> = Result<T, ApiResponse<S>>;Expand description
A convenient alias for a Result type where the error is an ApiResponse.
Aliased Type
pub enum ApiResult<T, S> {
Ok(T),
Err(ApiResponse<S>),
}pub type ApiResult<T, S> = Result<T, ApiResponse<S>>;A convenient alias for a Result type where the error is an ApiResponse.
pub enum ApiResult<T, S> {
Ok(T),
Err(ApiResponse<S>),
}