pub struct ErrorSet<T, E> { /* private fields */ }Expand description
An error defined by a set of possible status codes.
The parameter T is the actual value of the error, and must implement
IntoResponseWith.
The parameter E is a type-level set of possible status codes that this error
can have. e.g. (NotFound, InternalServerError) means that this error can either
be a 404 or a 500.
Implementations
Sourceimpl<T, E> ErrorSet<T, E>
impl<T, E> ErrorSet<T, E>
Sourcepub fn new_with<R: StatusWrapper>(value: T) -> Selfwhere
E: Contains<R>,
pub fn new_with<R: StatusWrapper>(value: T) -> Selfwhere
E: Contains<R>,
Create a new [ApiError] with the given wrapper-type.
Checks at compile time that the status code is part of the set E.
Sourcepub fn new<R: StatusWrapper>(value: R) -> Self
pub fn new<R: StatusWrapper>(value: R) -> Self
Create a new [ApiError] with the given wrapper from a type that implements
StatusWrapper. (e.g. NotFound<YourValue>)
Checks at compile time that the status code is part of the set E.
Sourcepub fn new_unchecked(value: T, code: StatusCode) -> Self
pub fn new_unchecked(value: T, code: StatusCode) -> Self
Create a new [ApiError] with the given value and status code.
This does not check that the status code is part of the set E. Be careful when
using this method, as it can lead to invalid [ApiError]s.
Sourcepub fn into_parts(self) -> (T, StatusCode)
pub fn into_parts(self) -> (T, StatusCode)
Convert this [ApiError] into a tuple of the value and the status code.
Sourcepub fn into_superset<E2>(self) -> ErrorSet<T, E2>where
E2: SupersetOf<E>,
pub fn into_superset<E2>(self) -> ErrorSet<T, E2>where
E2: SupersetOf<E>,
Convert this [ApiError] into a new [ApiError] with a superset of the original
set of status codes.
Sourcepub fn map_value<F, U>(self, f: F) -> ErrorSet<U, E>where
F: FnOnce(T) -> U,
pub fn map_value<F, U>(self, f: F) -> ErrorSet<U, E>where
F: FnOnce(T) -> U,
Convert this [ApiError] into a new [ApiError] with a different value type.
Sourcepub fn status_code(&self) -> StatusCode
pub fn status_code(&self) -> StatusCode
Get the status code of this [ApiError].