pub trait StatusWrapper: Sized {
type Inner;
type Pure: StatusWrapper;
const STATUS_CODE: StatusCode;
// Required method
fn into_inner(self) -> Self::Inner;
// Provided method
fn into_set<T, E>(self) -> ErrorSet<T, E>
where E: Contains<Self::Pure>,
Self::Inner: Into<T> { ... }
}Expand description
Implemented for all types that can be used as E inside [ApiError<_, E>].
implemented for NotFound,
InternalServerError, etc.
Required Associated Constants
Sourceconst STATUS_CODE: StatusCode
const STATUS_CODE: StatusCode
The status code associated with type.
Required Associated Types
Sourcetype Pure: StatusWrapper
type Pure: StatusWrapper
The pure type of this status wrapper, without any inner value.
Required Methods
Sourcefn into_inner(self) -> Self::Inner
fn into_inner(self) -> Self::Inner
Convert this status wrapper into its inner value.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".